# config_tpg Changelog

## 0.1.5  / 2025-03-10

- Update diagram
- Update doc on methods
- Update comments in configparms_ext
- Reorder methods in configparms_ext to follow processing order

## 0.1.4  / 2025-03-10

- fix remove comments and verify order

## 0.1.3  / 2025-03-10

- Code tag out of synch with package wheel
- Fix reading of list from config, strip spaces

## 0.1.2  / 2025-02-03

- Fix reading of list from config, strip spaces
- Documentation update

## 0.1.1  / 2025-01-07

- Documentation update

## 0.1.0  / 2025-01-07

- Initial public release

## 0.0.17 / 2025-01-03

- change name to config_tpg
- cleanup code comments 
- update keywords for package

## 0.0.16 / 2024-12-29

- corrected testing in gitlab pipeline
- update doc

## 0.0.15 / 2024-12-28

 - add examples to customization doc
 - pass config, sec, vars to customization methods

## 0.0.14 / 2024-12-27

 - update flowchart and doc 
 - change config-init to config_tpg-init

## 0.0.12-13 / 2024-12-21

- update version test, prefix name changed in 3.12, not 3.11
- add hooks to customize cfg variables
- add flowchart

## 0.0.11 / 2024-12-18

- correct set_directories method to base off src.config.py
- fix the pipeline test script

## 0.0.10 / 2024-12-18

- testing of versioning

## 0.0.9  / 2024-12-17

- add scm version control which uses git tags
- update change log

## 0.0.8 / 2024-12-16

- Update documentation

## 0.0.7 / 2024-12-16

- Correct links to gitlab repository

## 0.0.6 / 2024-12-15

- Add this file
- Version is fixed in toml and

## 0.0.2 to 0.0.5 / 2024-12-11

- Update README.md
- Fixes to toml file
- Experiment with version and change log 

## 0.0.1 / 2024-12-10

- Initial load of package to test